# Cenergy

This is our developed approach and openly released software that automate the generation of digital 3D urban energy model from open data. We synthesize data from OpenTopography, OpenStreetMap, and Overture Maps in generating 3D models. The rendered model visualizes and contextualizes distribution power grids alongside the built environment and transportation networks. Our developed software, including an open python library and a free [API](https://arxiv.org/pdf/2512.06459), provides interactive figures for the 3D models. The rendered models are essential for analyzing infrastructure alignment and spatially linking energy demand nodes (buildings) with energy supply (utility grids). The developed API leverages standard Web Mercator coordinates (EPSG:3857) and JSON serialization to ensure interoperability within smart city and energy simulation platforms. We also provide a [graphic user interface (GUI)](https://sites.google.com/view/cenergy3/home) where end-users can access our API via a cloud-based server, regardless of their programming skills and what devices and platforms their are using.
